import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import {Tost} from "karaui";
import NickName from './nickName'
import Intro from './intro'
import HeadIcon from './headIcon'


@inject('UCInfoStore', 'ConfigStore')
@observer
class UCInfo extends Component {
  constructor(props) {
    super(props)
  }

  componentDidMount() {
    this.props.ConfigStore.config.httpAgent.get('/account/getCurrentAccountCard').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.UCInfoStore.getUserCard(res)
        }
        else {
          Tost({type: 'error', msg: '获取用户信息失败', time: 4})
        }
      }
    )
  }

  fomateDate = (strDate, type) => {
    if (!strDate) {
      if (type === 0) {
        return ' 月 日'
      }
      else {
        return '年 月 日'
      }
    }

    let dateStr = strDate.replace(/00:00:00/, "");
    let dateArr = dateStr.split("-");

    // let da = new Date(strDate.replace(/00:00:00/, ""));
    // let year = da.getFullYear() + '年'
    // let month = (da.getMonth() + 1 < 10 ? '0' + (da.getMonth() + 1) : da.getMonth() + 1) + '月'
    // let date = (da.getDate() < 10 ? '0' + (da.getDate()) : da.getDate()) + '日' let year = da.getFullYear() + '年'
    let year = dateArr[0] + '年'
    let month = dateArr[1] + '月'
    let date = dateArr[2] + '日'
    if (type === 0) {
      return [month, date].join('')
    }
    else {
      return [year, month, date].join('')
    }
  }

  render() {
    const {UCInfoStore, ConfigStore, lang} = this.props;
    const {karaui} = ConfigStore.config
    const {Scroll} = karaui
    if (ConfigStore === undefined || UCInfoStore === undefined) {
      return null
    }
    const {httpAgent} = ConfigStore.config
    const {updateNickName, updateSign} = UCInfoStore
    let user = ConfigStore.config.user

    const {
      accountId, accountName, bgId, birthDay, companyName, costCenterName, emailAddress, headIcon,
      hireDay, hireDayCount, mobile, nickName, ntAccount, office, organizationName, parentAccountName, sameBirthDayCount, sbuName,
      signature, staffCode, tags, workingLocation
    } = UCInfoStore.userCard;

    if (!UCInfoStore.userCard) {
      return null;
    }
    return (
      <div className={css.UCInfo}>
        <Scroll>
          <HeadIcon headIcon={headIcon} user={user} lang={lang} httpAgent={httpAgent}
                    UCInfoStore={UCInfoStore}/>
          <div className={css.nickName}>
            <NickName lang={lang} nickName={nickName} httpAgent={httpAgent}
                      updateNickName={updateNickName}/>
            <Intro lang={lang} signature={signature} httpAgent={httpAgent}
                   updateSign={updateSign}/>
          </div>
          <div className={`clearfix ${css.workInfo}`}>
            <div><span className='s-hint'>NT</span><span>{ntAccount}</span></div>
            <div><span className='s-hint'>{lang.emId}</span><span>{staffCode}</span></div>
            <div><span className={`s-hint`}>{lang.email}</span><span>{emailAddress}</span></div>
            <div><span className='s-hint'>{lang.tel}</span><span>{office}</span></div>
            <div><span className='s-hint'>{lang.phone}</span><span>{mobile}</span></div>
            <div><span className={`s-hint`}>BG</span><span>{bgId}</span></div>
            <div><span className='s-hint'>BU</span><span>{sbuName}</span></div>
            <div><span className='s-hint'>{lang.company}</span><span>{companyName}</span></div>
            <div><span className={`s-hint`}>CC</span><span>{costCenterName}</span></div>
            <div><span className='s-hint'>{lang.department}</span><span>{organizationName}</span></div>
            <div><span className='s-hint'>{lang.superior}</span><span>{parentAccountName}</span></div>
            <div><span className={`s-hint`}>{lang.workStation}</span><span>{workingLocation}</span>
            </div>
            <div className={css.full}><span
              className='s-hint'>{lang.label}</span><span>{tags}</span></div>
          </div>
          <div className={css.brithday}>
            <div><span
              className='s-hint'>{lang.birthday}</span><span>{this.fomateDate(birthDay, 0)}</span><span>共{sameBirthDayCount}名同学与您同一天生日</span>
            </div>
            <div><span
              className='s-hint'>{lang.entryDate}</span><span>{this.fomateDate(hireDay, 1)}</span><span>您加入亚信大家庭已经{hireDayCount}天了，感谢您的辛苦付出</span>
            </div>
          </div>
        </Scroll>
      </div>
    )
  }
}

export default UCInfo
